@@ -1,11 +1,12 @@
 from argparse import ArgumentParser
 from difflib import _mdiff as mdiff, SequenceMatcher
 from html import escape
+from pathlib import Path
 from re import compile
 from string import whitespace
 from sys import exit, stderr, stdout
 
-VERSION = '0.2.0'
+VERSION = '0.3.0'
 
 SKIPS = [
     compile(r'^.*\[?[Pp]age [0-9ivx]+\]?[ \t\f]*$'),
@@ -16,14 +17,15 @@ SKIPS = [
     compile(r'^draft-[-a-z0-9_.]+.*[0-9][0-9][0-9][0-9]$')]
 
 TABLE = """
-    <table cellspacing="0" cellpadding="0">
-      <tr>
-        <td>&nbsp;</td>
-        <th class="header">{filename1}</th>
-        <td>&nbsp;</td>
-        <th class="header">{filename2}</th>
-      </tr>
-      {rows}
+    <table>
+      <tbody>
+        <tr>
+          <td>&nbsp;</td>
+          <th class="header" scope="col">{filename1}</th>
+          <td>&nbsp;</td>
+          <th class="header" scope="col">{filename2}</th>
+        </tr>{rows}
+      </tbody>
     </table>"""
 
 HTML = """
@@ -31,15 +33,20 @@ HTML = """
 <html lang="en">
   <head>
     <meta charset="utf-8">
-    <title></title>
+    <title>{title}</title>
     <style>
       body {{font-family: monospace}}
+      table {{
+        border-spacing: 0;
+      }}
       td {{
+        padding: 0;
         white-space: pre;
         vertical-align: top;
         font-size: 0.86em;
       }}
       th {{
+        padding: 0;
         text-align: center;
       }}
       .left {{ background-color: #EEE; }}
@@ -60,9 +67,7 @@ HTML = """
       }}
     </style>
   </head>
-  <body>
-    {output}
-  </body>
+  <body>{output}</body>
 </html>"""
 
 UNCHANGED_ROW = """
@@ -90,20 +95,20 @@ CONTEXT_LINE = """
       </tr>
       <tr id="context-{context}">
         <td></td>
-        <th class="change">
+        <th class="change" scope="col">
           <a href="#context-{context}">
            <small>Skipping</small>
           </a>
         </th>
         <td></td>
-        <th class="change">
+        <th class="change" scope="col">
           <a href="#context-{context}">
            <small>Skipping</small>
           </a>
         </th>
       </tr>"""
 
-WHITESPACES = ''.join([
+WHITESPACE = ''.join([
     whitespace,  # python stirng.whitespace
     '\u0009',    # character tabulation
     '\u000A',    # line feed
@@ -138,16 +143,22 @@ WHITESPACES = ''.join([
     '\uFEFF'])   # zero width non-breaking space
 
 
-def cleanup(lines, skip_whitespaces):
+def get_filename(filename):
+    '''Return HTML escaped filename form user input path'''
+
+    return escape(Path(filename).name)
+
+
+def cleanup(lines, skip_whitespace):
     '''Removes skippable content, shrinks multiple empty lines
-    If a link only contains WHITESPACES,
-    that line will get stripped of any WHITESPACES.'''
+    If a link only contains WHITESPACE,
+    that line will get stripped of any WHITESPACE.'''
 
     id_lines = []
-    if skip_whitespaces:
+    if skip_whitespace:
         previous_blank = False
         for line in lines:
-            if len(line.strip(WHITESPACES)) > 0:
+            if len(line.strip(WHITESPACE)) > 0:
                 previous_blank = False
                 keep = True
                 for skip in SKIPS:
@@ -157,7 +168,7 @@ def cleanup(lines, skip_whitespaces):
                 if keep:
                     id_lines.append(line)
             elif not previous_blank:
-                id_lines.append(line.strip(WHITESPACES))
+                id_lines.append(line.strip(WHITESPACE))
                 previous_blank = True
     else:
         for line in lines:
@@ -173,7 +184,7 @@ def cleanup(lines, skip_whitespaces):
 
 def add_span(line, css_class):
     '''Add span tag with the class'''
-    stripped_line = line.strip('\0+-^\1').strip(WHITESPACES)
+    stripped_line = line.strip('\0+-^\1').strip(WHITESPACE)
     if len(stripped_line) == 0:
         return ''
     else:
@@ -192,21 +203,21 @@ def get_wdiff(first_id_lines, second_id_lines):
                           b=second_id_lines)
     for tag, f1, f2, s1, s2 in seq.get_opcodes():
         if tag == 'equal':
-            rows += first_id_lines[f1:f2]
+            rows += escape(first_id_lines[f1:f2])
         elif tag == 'delete':
             rows += '<span class="w-delete">{}</span>'.format(
-                        first_id_lines[f1:f2])
+                        escape(first_id_lines[f1:f2]))
         elif tag == 'replace':
             rows += '<span class="w-delete">{}</span>'.format(
-                        first_id_lines[f1:f2])
+                        escape(first_id_lines[f1:f2]))
             rows += '<span class="w-insert">{}</span>'.format(
-                        second_id_lines[s1:s2])
+                        escape(second_id_lines[s1:s2]))
         elif tag == 'insert':
             rows += '<span class="w-insert">{}</span>'.format(
-                        second_id_lines[s1:s2])
+                        escape(second_id_lines[s1:s2]))
     output = '<pre>{}</pre>'.format(rows)
 
-    return HTML.format(output=output)
+    return output
 
 
 def get_diff_rows(first_id_lines, second_id_lines, context):
@@ -234,34 +245,40 @@ def get_diff_rows(first_id_lines, second_id_lines, context):
 
 def get_html_table(filename1, filename2, rows):
     '''Return HTML table'''
-    return TABLE.format(filename1=escape(filename1),
-                        filename2=escape(filename2),
+    return TABLE.format(filename1=get_filename(filename1),
+                        filename2=get_filename(filename2),
                         rows=rows)
 
 
 def get_iddiff(file1, file2, context_lines=None, table_only=False,
-               wdiff=False, skip_whitespaces=False):
+               wdiff=False, skip_whitespace=False):
     '''Return iddiff output'''
 
+    title = 'Diff: {file1} - {file2}'.format(
+                                        file1=get_filename(file1),
+                                        file2=get_filename(file2))
+
     if wdiff:
         with open(file1, 'r') as file:
-            id_a_lines = ''.join(cleanup(file.readlines(), skip_whitespaces))
+            id_a_lines = ''.join(cleanup(file.readlines(), skip_whitespace))
         with open(file2, 'r') as file:
-            id_b_lines = ''.join(cleanup(file.readlines(), skip_whitespaces))
+            id_b_lines = ''.join(cleanup(file.readlines(), skip_whitespace))
 
         output = get_wdiff(id_a_lines, id_b_lines)
+
+        output = HTML.format(output=output, title=title)
     else:
         with open(file1, 'r') as file:
-            id_a_lines = cleanup(file.readlines(), skip_whitespaces)
+            id_a_lines = cleanup(file.readlines(), skip_whitespace)
         with open(file2, 'r') as file:
-            id_b_lines = cleanup(file.readlines(), skip_whitespaces)
+            id_b_lines = cleanup(file.readlines(), skip_whitespace)
 
         rows = get_diff_rows(id_a_lines, id_b_lines, context_lines)
 
         output = get_html_table(file1, file2, rows)
 
         if not table_only:
-            output = HTML.format(output=output)
+            output = HTML.format(output=output, title=title)
 
     return output
 
@@ -269,21 +286,39 @@ def get_iddiff(file1, file2, context_lines=None, table_only=False,
 def parse_args(args=None):
     '''Parse command line arguments and return options'''
     parser = ArgumentParser(description='Internet-Draft diff tool')
-    parser.add_argument('-t', '--table', action='store_true', default=False,
-                        help='produce a HTML table (default)')
-    parser.add_argument('-c', '--context', action='store_true', default=False,
-                        help='produce a context (default)')
-    parser.add_argument('-l', '--lines', type=int, default=8,
-                        help='set number of context lines (default 8)')
-    parser.add_argument('-w', '--wdiff', action='store_true', default=False,
-                        help='produce word difference')
-    parser.add_argument('-s', '--skip-whitespaces', action='store_true',
+
+    main_group = parser.add_mutually_exclusive_group()
+    main_group.add_argument('--side-by-side',
+                            action='store_true',
+                            default=True,
+                            help='side by side difference (default)')
+    main_group.add_argument('-w', '--wdiff',
+                            action='store_true',
+                            default=False,
+                            help='produce word difference')
+
+    group = parser.add_argument_group('side by side options')
+    group.add_argument('-t', '--table-only',
+                       action='store_true',
+                       default=False,
+                       help='produce only a HTML table')
+    group.add_argument('-c', '--context-lines',
+                       type=int,
+                       default=8,
+                       help='set number of context lines (set to 0 for no '
+                            'context) (default 8)')
+
+    parser.add_argument('-s', '--skip-whitespace',
+                        action='store_true',
                         default=False,
-                        help='skip multilines with only whitespaces')
-    parser.add_argument('file1')
-    parser.add_argument('file2')
-    parser.add_argument('--version', action='version',
+                        help='skip multilines with only whitespace')
+    parser.add_argument('--version',
+                        action='version',
                         version='iddiff {}'.format(VERSION))
+
+    parser.add_argument('file1', help='first file to compare')
+    parser.add_argument('file2', help='second file to compare')
+
     return parser.parse_args(args)
 
 
@@ -292,18 +327,18 @@ def main():
 
     file1 = options.file1
     file2 = options.file2
-    if options.context:
-        context_lines = options.lines
-    else:
+    if options.context_lines == 0:
         context_lines = None
+    else:
+        context_lines = options.context_lines
 
     try:
         iddiff = get_iddiff(file1=file1,
                             file2=file2,
                             context_lines=context_lines,
-                            table_only=options.table,
+                            table_only=options.table_only,
                             wdiff=options.wdiff,
-                            skip_whitespaces=options.skip_whitespaces)
+                            skip_whitespace=options.skip_whitespace)
         stdout.writelines(iddiff)
     except FileNotFoundError as e:
         stderr.write('iddiff: {}.\n'.format(e))
